aboutsummaryrefslogtreecommitdiffhomepage
path: root/demoisa
diff options
context:
space:
mode:
authorGravatar David Aspinall <da@inf.ed.ac.uk>1999-11-17 19:01:16 +0000
committerGravatar David Aspinall <da@inf.ed.ac.uk>1999-11-17 19:01:16 +0000
commit72ce989f5e85280d78d597534406ec686e9edb64 (patch)
treed0f51bdb550eddda5b4f7b594b151f15dfa2e33b /demoisa
parentef8fa6c51e097238da726ccdf245db82b9001ec2 (diff)
Fixed some docstrings
Diffstat (limited to 'demoisa')
-rw-r--r--demoisa/demoisa-easy.el11
1 files changed, 7 insertions, 4 deletions
diff --git a/demoisa/demoisa-easy.el b/demoisa/demoisa-easy.el
index 71262d03..d1407fe1 100644
--- a/demoisa/demoisa-easy.el
+++ b/demoisa/demoisa-easy.el
@@ -1,4 +1,4 @@
;; proof-easy.el Example Proof General instance for Isabelle
;;
;; Copyright (C) 1999 LFCS Edinburgh.
;;
@@ -7,12 +7,13 @@
;; $Id$
;;
;; This is an alternative version of demoisa.el which uses the
-;; proof-easy-config mechanism to avoid declaring derived modes, etc.
-;; NB: proof-easy-config is experimental.
+;; proof-easy-config macro to do the work of declaring derived modes,
+;; etc. NB: proof-easy-config is currently experimental.
;;
-;; See demoisa.el for documentation.
+;; See demoisa.el and the Proof General manual for more documentation.
;;
;; To test this file you must rename it demoisa.el.
+;;
(require 'proof-easy-config) ; easy configure mechanism
@@ -51,3 +52,5 @@
"\\(\\(.\\|\n\\)*No subgoals!\n\\)"
proof-shell-eager-annotation-start
"^\\[opening \\|^###\\|^Reading")
+
+(provide 'demoisa) \ No newline at end of file
@@ -1,4 +1,4 @@
-;; proof-easy.el Example Proof General instance for Isabelle
+;; demoisa-easy.el Example Proof General instance for Isabelle
;;
;; Copyright (C) 1999 LFCS Edinburgh.